@@ -52,6 +52,14 @@ class IncorrectNumberOfSubstation(EnvError):
     pass
 
 
+class IncorrectNumberOfStorages(EnvError):
+    """
+    This is a more precise exception than :class:`EnvError` indicating that there is a mismatch in the total
+    number of storage of the powergrid.
+    """
+    pass
+
+
 class IncorrectNumberOfElements(EnvError):
     """
     This is a more precise exception than :class:`EnvError` indicating that there is a mismatch in the total number
@@ -59,6 +67,7 @@ class IncorrectNumberOfElements(EnvError):
     """
     pass
 
+
 class IncorrectPositionOfLoads(EnvError):
     """
     This is a more precise exception than :class:`EnvError` indicating that there is a mismatch in the number of
@@ -73,6 +82,8 @@ class IncorrectPositionOfGenerators(EnvError):
     generators at a substation.
     """
     pass
+
+
 class IncorrectPositionOfLines(EnvError):
     """
     This is a more precise exception than :class:`EnvError` indicating that there is a mismatch in the number of
@@ -80,7 +91,16 @@ class IncorrectPositionOfLines(EnvError):
     """
     pass
 
-# Unknown environment at creating
+
+class IncorrectPositionOfStorages(EnvError):
+    """
+    This is a more precise exception than :class:`EnvError` indicating that there is a mismatch in the number of
+    storage unit at a substation.
+    """
+    pass
+
+
+# Unknown environment at creation
 class UnknownEnv(Grid2OpException):
     """
     This exception indicate that a bad argument has been sent to the :func:`grid2op.make` function.
@@ -89,6 +109,7 @@ class UnknownEnv(Grid2OpException):
     """
     pass
 
+
 # multi environment
 class MultiEnvException(Grid2OpException):
     """General exception raised by :class:`grid2Op.MultiEnv.MultiEnvironment` """
