@@ -101,6 +101,7 @@ def _check_path(path, info):
 
 
 def make_from_dataset_path(dataset_path="/",
+                           experimental_read_from_local_dir=False,
                            _add_to_name="",
                            _compat_glop_version=None,
                            **kwargs):
@@ -547,6 +548,18 @@ def make_from_dataset_path(dataset_path="/",
                                                msg_error=ERR_MSG_KWARGS["kwargs_attention_budget"],
                                                isclass=False)
 
+    if experimental_read_from_local_dir:
+        sys_path = os.path.join(os.path.split(grid_path_abs)[0], "_grid2op_classes")
+        if not os.path.exists(sys_path):
+            raise RuntimeError("Attempting to load the grid classes from the env path. Yet the directory "
+                               "where they should be placed does not exists. Did you call `env.generate_classes()` "
+                               "BEFORE creating an environment with `experimental_read_from_local_dir=True` ?")
+        if not os.path.isdir(sys_path) or not os.path.exists(os.path.join(sys_path, "__init__.py")):
+            raise RuntimeError(f"Impossible to load the classes from the env path. There is something that is "
+                               f"not a directory and that is called `_grid2op_classes`. "
+                               f"Please remove \"{sys_path}\" and call `env.generate_classes()` where env is an "
+                               f"environment created with `experimental_read_from_local_dir=False` (default)")
+
     # Finally instantiate env from config & overrides
     env = Environment(init_grid_path=grid_path_abs,
                       chronics_handler=data_feeding,
@@ -571,7 +584,8 @@ def make_from_dataset_path(dataset_path="/",
                       has_attention_budget=has_attention_budget,
                       attention_budget_cls=attention_budget_class,
                       kwargs_attention_budget=kwargs_attention_budget,
-                      _compat_glop_version=_compat_glop_version
+                      _compat_glop_version=_compat_glop_version,
+                      _read_from_local_dir=experimental_read_from_local_dir,
                       )
 
     # Update the thermal limit if any
