@@ -5,6 +5,7 @@ __all__ = [
     "list_available_local_env",
     "get_current_local_dir",
     "change_local_dir",
+    "list_available_test_env",
     "update_env",
     # deprecated in v 0.8.0
     "make_old"
@@ -13,5 +14,6 @@ __all__ = [
 from grid2op.MakeEnv.MakeOld import make_old
 from grid2op.MakeEnv.MakeFromPath import make_from_dataset_path
 from grid2op.MakeEnv.Make import make
-from grid2op.MakeEnv.UserUtils import list_available_remote_env, list_available_local_env, get_current_local_dir, change_local_dir
+from grid2op.MakeEnv.UserUtils import list_available_remote_env, list_available_local_env, get_current_local_dir
+from grid2op.MakeEnv.UserUtils import change_local_dir, list_available_test_env
 from grid2op.MakeEnv.UpdateEnv import update_env
