@@ -99,6 +99,13 @@ class Parameters:
 
         Default: ``True``
 
+    ALARM_BEST_TIME: ``int``
+        Number of step for which it's best to send an alarm BEFORE a game over
+
+    ALARM_WINDOW_SIZE: ``int``
+        Number of steps for which it's worth it to give an alarm (if an alarm is send outside of the window
+        `[ALARM_BEST_TIME - ALARM_WINDOW_SIZE, ALARM_BEST_TIME + ALARM_WINDOW_SIZE]` then it does not grant anything
+
     """
     def __init__(self, parameters_path=None):
         """
@@ -161,6 +168,9 @@ class Parameters:
                 warn_msg = "Parameters: the file {} is not found. Continuing with default parameters."
                 warnings.warn(warn_msg.format(parameters_path))
 
+        self.ALARM_BEST_TIME = 12
+        self.ALARM_WINDOW_SIZE = 12
+
     @staticmethod
     def _isok_txt(arg):
         if isinstance(arg, type(True)):
@@ -247,6 +257,12 @@ class Parameters:
         if "ACTIVATE_STORAGE_LOSS" in dict_:
             self.ACTIVATE_STORAGE_LOSS = Parameters._isok_txt(dict_["ACTIVATE_STORAGE_LOSS"])
 
+        # alarm parameters
+        if "ALARM_BEST_TIME" in dict_:
+            self.ALARM_BEST_TIME = dt_int(dict_["ALARM_BEST_TIME"])
+        if "ALARM_WINDOW_SIZE" in dict_:
+            self.ALARM_WINDOW_SIZE = dt_int(dict_["ALARM_WINDOW_SIZE"])
+
         authorized_keys = set(self.__dict__.keys())
         authorized_keys = authorized_keys | {'NB_TIMESTEP_POWERFLOW_ALLOWED',
                                              'NB_TIMESTEP_TOPOLOGY_REMODIF',
@@ -281,6 +297,8 @@ class Parameters:
         res["NB_TIMESTEP_COOLDOWN_SUB"] = int(self.NB_TIMESTEP_COOLDOWN_SUB)
         res["INIT_STORAGE_CAPACITY"] = float(self.INIT_STORAGE_CAPACITY)
         res["ACTIVATE_STORAGE_LOSS"] = bool(self.ACTIVATE_STORAGE_LOSS)
+        res["ALARM_BEST_TIME"] = int(self.ALARM_BEST_TIME)
+        res["ALARM_WINDOW_SIZE"] = int(self.ALARM_WINDOW_SIZE)
         return res
 
     def init_from_json(self, json_path):
@@ -300,7 +318,12 @@ class Parameters:
             warn_msg = "Could not load from {}\n" \
                        "Continuing with default parameters. \n\nThe error was \"{}\""
             warnings.warn(warn_msg.format(json_path, exc_))
-        
+
+    def __eq__(self, other):
+        this_dict = self.to_dict()
+        other_dict = other.to_dict()
+        return this_dict == other_dict
+
     @staticmethod
     def from_json(json_path):
         """
@@ -426,3 +449,17 @@ class Parameters:
             self.ACTIVATE_STORAGE_LOSS = dt_bool(self.ACTIVATE_STORAGE_LOSS)
         except Exception as exc_:
             raise RuntimeError(f"Impossible to convert ACTIVATE_STORAGE_LOSS to bool with error \n:\"{exc_}\"")
+
+        try:
+            self.ALARM_WINDOW_SIZE = dt_int(self.ALARM_WINDOW_SIZE)
+        except Exception as exc_:
+            raise RuntimeError(f"Impossible to convert ALARM_WINDOW_SIZE to int with error \n:\"{exc_}\"")
+        try:
+            self.ALARM_BEST_TIME = dt_int(self.ALARM_BEST_TIME)
+        except Exception as exc_:
+            raise RuntimeError(f"Impossible to convert ALARM_BEST_TIME to int with error \n:\"{exc_}\"")
+
+        if self.ALARM_WINDOW_SIZE <= 0:
+            raise RuntimeError("self.ALARM_WINDOW_SIZE should be a positive integer !")
+        if self.ALARM_BEST_TIME <= 0:
+            raise RuntimeError("self.ALARM_BEST_TIME should be a positive integer !")
