@@ -108,21 +108,16 @@ class TestL2RPNSCORE(HelperTests):
             assert os.path.exists(os.path.join(env.get_path_env(),
                                                EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
             assert os.path.exists(os.path.join(env.get_path_env(),
-                                               EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
+                                               EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
             # delete them
-            stats_0 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN)
-            stats_1 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)
-            stats_2 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)
-            stats_0.clear_all()
-            stats_1.clear_all()
-            stats_2.clear_all()
+            scores.clear_all()
             assert not os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
+            # assert not os.path.exists(os.path.join(env.get_path_env(),
+            #                                       EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
             assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
-            assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
     def test_donothing_0(self):
         """test that do nothing has a score of 0.00"""
@@ -135,25 +130,20 @@ class TestL2RPNSCORE(HelperTests):
                 assert os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
                 assert os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
                 my_agent = DoNothingAgent(env.action_space)
                 my_scores, *_ = scores.get(my_agent)
                 assert np.max(np.abs(my_scores)) <= self.tol_one
 
             # delete them
-            stats_0 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN)
-            stats_1 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)
-            stats_2 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)
-            stats_0.clear_all()
-            stats_1.clear_all()
-            stats_2.clear_all()
+            scores.clear_all()
             assert not os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
+            # assert not os.path.exists(os.path.join(env.get_path_env(),
+            #                                        EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
             assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
-            assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
     def test_modif_max_step_decrease(self):
         """
@@ -169,7 +159,7 @@ class TestL2RPNSCORE(HelperTests):
                 assert os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
                 assert os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
                 my_agent = DoNothingAgent(env.action_space)
                 my_scores, *_ = scores.get(my_agent)
@@ -177,24 +167,19 @@ class TestL2RPNSCORE(HelperTests):
 
                 scores2 = ScoreL2RPN2020(env, nb_scenario=2, verbose=0, max_step=10)
                 assert not scores2._recomputed_dn
-                assert not scores2._recomputed_no_ov
+                assert not scores2._recomputed_no_ov_rp
                 my_agent = DoNothingAgent(env.action_space)
                 my_scores2, *_ = scores2.get(my_agent)
                 assert np.max(np.abs(my_scores2)) <= self.tol_one, "error for the second do nothing"
 
             # delete them
-            stats_0 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN)
-            stats_1 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)
-            stats_2 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)
-            stats_0.clear_all()
-            stats_1.clear_all()
-            stats_2.clear_all()
+            scores.clear_all()
             assert not os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
+            # assert not os.path.exists(os.path.join(env.get_path_env(),
+            #                                        EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
             assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
-            assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
     def test_modif_max_step_increase(self):
         """test that i can modify the max step (and that if I increase it it does trigger a recomputation)"""
@@ -207,7 +192,7 @@ class TestL2RPNSCORE(HelperTests):
                 assert os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
                 assert os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
                 my_agent = DoNothingAgent(env.action_space)
                 my_scores, *_ = scores.get(my_agent)
@@ -215,21 +200,16 @@ class TestL2RPNSCORE(HelperTests):
 
                 scores2 = ScoreL2RPN2020(env, nb_scenario=2, verbose=0, max_step=10)
                 assert scores2._recomputed_dn
-                assert scores2._recomputed_no_ov
+                assert scores2._recomputed_no_ov_rp
 
             # delete them
-            stats_0 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN)
-            stats_1 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)
-            stats_2 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)
-            stats_0.clear_all()
-            stats_1.clear_all()
-            stats_2.clear_all()
+            scores.clear_all()
             assert not os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
+            # assert not os.path.exists(os.path.join(env.get_path_env(),
+            #                                        EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
             assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
-            assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
     def test_modif_nb_scenario(self):
         """
@@ -245,7 +225,7 @@ class TestL2RPNSCORE(HelperTests):
                 assert os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
                 assert os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
                 my_agent = DoNothingAgent(env.action_space)
                 my_scores, *_ = scores.get(my_agent)
@@ -253,25 +233,21 @@ class TestL2RPNSCORE(HelperTests):
 
                 scores2 = ScoreL2RPN2020(env, nb_scenario=4, verbose=0, max_step=5)
                 assert scores2._recomputed_dn
-                assert scores2._recomputed_no_ov
+                assert scores2._recomputed_no_ov_rp
 
                 scores2 = ScoreL2RPN2020(env, nb_scenario=3, verbose=0, max_step=5)
                 assert not scores2._recomputed_dn
-                assert not scores2._recomputed_no_ov
+                assert not scores2._recomputed_no_ov_rp
 
             # delete them
-            stats_0 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN)
-            stats_1 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)
-            stats_2 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)
-            stats_0.clear_all()
-            stats_1.clear_all()
-            stats_2.clear_all()
+            # delete them
+            scores.clear_all()
             assert not os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
+            # assert not os.path.exists(os.path.join(env.get_path_env(),
+            #                                        EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
             assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
-            assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
     def test_reco_noov_80(self):
         """test that do nothing has a score of 80.0 if it is run with "no overflow disconnection" """
@@ -281,14 +257,13 @@ class TestL2RPNSCORE(HelperTests):
                 # I cannot decrease the max step: it must be above the number of steps the do nothing does
                 scores = ScoreL2RPN2020(env, nb_scenario=2, verbose=0, max_step=130)
                 assert scores._recomputed_dn
-                assert scores._recomputed_no_ov
                 assert scores._recomputed_no_ov_rp
 
                 # the statistics have been properly computed
                 assert os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
                 assert os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
                 my_agent = DoNothingAgent(env.action_space)
                 my_scores, *_ = scores.get(my_agent)
@@ -299,25 +274,20 @@ class TestL2RPNSCORE(HelperTests):
             with make("rte_case5_example", test=True, param=param) as env:
                 scores2 = ScoreL2RPN2020(env, nb_scenario=2, verbose=0, max_step=130)
                 assert not scores2._recomputed_dn
-                assert not scores2._recomputed_no_ov
                 assert not scores2._recomputed_no_ov_rp
                 my_agent = RecoPowerlineAgent(env.action_space)
                 my_scores, *_ = scores2.get(my_agent)
                 assert np.max(np.abs(np.array(my_scores) - 80.0)) <= self.tol_one
 
             # delete them
-            stats_0 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN)
-            stats_1 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)
-            stats_2 = EpisodeStatistics(env, ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)
-            stats_0.clear_all()
-            stats_1.clear_all()
-            stats_2.clear_all()
+            # delete them
+            scores.clear_all()
             assert not os.path.exists(os.path.join(env.get_path_env(),
                                                    EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
+            # assert not os.path.exists(os.path.join(env.get_path_env(),
+            #                                        EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
             assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
-            assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
 
 class TestICAPSSCORE(HelperTests):
@@ -334,8 +304,8 @@ class TestICAPSSCORE(HelperTests):
                                         env_seeds=[1, 2],  # with these seeds do nothing goes till the end
                                         agent_seeds=[3, 4])
                 my_agent = DoNothingAgent(env.action_space)
-                scores, n_played, total_ts = scores.get(my_agent)
-                for (ep_score, op_score, alarm_score) in scores:
+                scores_this, n_played, total_ts = scores.get(my_agent)
+                for (ep_score, op_score, alarm_score) in scores_this:
                     assert np.abs(ep_score - 30.) <= self.tol_one, f"wrong score for the episode: {ep_score} vs 30."
                     assert np.abs(op_score - 0.) <= self.tol_one, f"wrong score for the operationnal cost: " \
                                                                   f"{op_score} vs 0."
@@ -346,21 +316,16 @@ class TestICAPSSCORE(HelperTests):
             assert os.path.exists(os.path.join(env.get_path_env(),
                                                EpisodeStatistics.get_name_dir(ScoreICAPS2021.NAME_DN)))
             assert os.path.exists(os.path.join(env.get_path_env(),
-                                               EpisodeStatistics.get_name_dir(ScoreICAPS2021.NAME_DN_NO_OVERWLOW)))
+                                               EpisodeStatistics.get_name_dir(ScoreICAPS2021.NAME_RP_NO_OVERFLOW)))
 
             # delete them
-            stats_0 = EpisodeStatistics(env, ScoreICAPS2021.NAME_DN)
-            stats_1 = EpisodeStatistics(env, ScoreICAPS2021.NAME_DN_NO_OVERWLOW)
-            stats_2 = EpisodeStatistics(env, ScoreICAPS2021.NAME_RP_NO_OVERWLOW)
-            stats_0.clear_all()
-            stats_1.clear_all()
-            stats_2.clear_all()
+            scores.clear_all()
             assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreICAPS2021.NAME_DN)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN)))
+            # assert not os.path.exists(os.path.join(env.get_path_env(),
+            #                                        EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_DN_NO_OVERWLOW)))
             assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreICAPS2021.NAME_DN_NO_OVERWLOW)))
-            assert not os.path.exists(os.path.join(env.get_path_env(),
-                                                   EpisodeStatistics.get_name_dir(ScoreICAPS2021.NAME_RP_NO_OVERWLOW)))
+                                                   EpisodeStatistics.get_name_dir(ScoreL2RPN2020.NAME_RP_NO_OVERFLOW)))
 
 
 if __name__ == "__main__":
